@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2011 by Pablo Martín <goinnn@gmail.com>
+# Copyright (c) 2013 by Pablo Martín <goinnn@gmail.com>
 #
 # This software is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -23,7 +23,6 @@ DJ_MENU = "Django"
 PY_CHECKERS = "Checkers"
 JS_MENU = "JavaScript"
 TOOLS_MENU = "Tools"
-JS_CHECKERS = "JavaScript"
 
 
 @kate.init
@@ -69,7 +68,7 @@ KATE_ACTIONS = {
     'insertReady': {'text': 'jQuery Ready', 'shortcut': 'Ctrl+J',
                     'menu': JS_MENU, 'icon': None},
     'checkJslint': {'text': 'JSLint', 'shortcut': 'Alt+9',
-                    'menu': JS_CHECKERS, 'icon': None},
+                    'menu': JS_MENU, 'icon': None},
     'togglePrettyJsonFormat': {'text': 'Pretty Json', 'shortcut': 'Ctrl+Alt+J',
                                'menu': JS_MENU, 'icon': None},
     'togglePrettyXMLFormat': {'text': 'Pretty XML', 'shortcut': 'Ctrl+Alt+X',
@@ -81,8 +80,8 @@ JAVASCRIPT_AUTOCOMPLETE_ENABLED = True
 JQUERY_AUTOCOMPLETE_ENABLED = True
 CHECKALL_TO_SAVE = True
 IGNORE_PEP8_ERRORS = []
-TEMPLATE_TAGS_CLOSE = ["autoescape", "block", "comment", "filter", "for", "if",
-                       "ifchanged", "ifequal", "spaceless", "with"]
+TEMPLATE_TAGS_CLOSE = ["autoescape", "block", "comment", "filter", "for",
+                       "ifchanged", "ifequal", "if", "spaceless", "with"]
 
 
 try:
